==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableIterator.h <==
// class java.util.Collections$UnmodifiableIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6114b171567504f8 java_util_Collections__24UnmodifiableIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24UnmodifiableIterator_H_
#define _JC_java_util_Collections__24UnmodifiableIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$sub_refs	_jc_java_util_Collections__24UnmodifiableIterator$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$refs	_jc_java_util_Collections__24UnmodifiableIterator$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$nonrefs	_jc_java_util_Collections__24UnmodifiableIterator$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$object	_jc_java_util_Collections__24UnmodifiableIterator$object;

typedef const struct _jc_java_util_Collections__24UnmodifiableIterator$vmethods	_jc_java_util_Collections__24UnmodifiableIterator$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableIterator$vtable	_jc_java_util_Collections__24UnmodifiableIterator$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableIterator$vtype	_jc_java_util_Collections__24UnmodifiableIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableIterator$method$_init$fb346656e80483e8(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24UnmodifiableIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *);
extern void _jc_java_util_Collections__24UnmodifiableIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_Collections__24UnmodifiableIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_Collections__24UnmodifiableIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *);
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableIterator$vmethods	java_util_Collections__24UnmodifiableIterator;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableIterator$sub_refs {
	struct _jc_object	*i;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableIterator$refs {
    _jc_java_util_Collections__24UnmodifiableIterator$sub_refs	java_util_Collections__24UnmodifiableIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs	java_util_Collections__24UnmodifiableIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableIterator$object {
	_jc_java_util_Collections__24UnmodifiableIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableIterator$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableIterator$vtype _jc_java_util_Collections__24UnmodifiableIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableIterator$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableIterator.h <==
// class java.util.Collections$UnmodifiableIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6114b171567504f8 java_util_Collections__24UnmodifiableIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24UnmodifiableIterator_H_
#define _JC_java_util_Collections__24UnmodifiableIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$sub_refs	_jc_java_util_Collections__24UnmodifiableIterator$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$refs	_jc_java_util_Collections__24UnmodifiableIterator$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$nonrefs	_jc_java_util_Collections__24UnmodifiableIterator$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableIterator$object	_jc_java_util_Collections__24UnmodifiableIterator$object;

typedef const struct _jc_java_util_Collections__24UnmodifiableIterator$vmethods	_jc_java_util_Collections__24UnmodifiableIterator$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableIterator$vtable	_jc_java_util_Collections__24UnmodifiableIterator$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableIterator$vtype	_jc_java_util_Collections__24UnmodifiableIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableIterator$method$_init$fb346656e80483e8(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24UnmodifiableIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24UnmodifiableIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_Collections__24UnmodifiableIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_Collections__24UnmodifiableIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableIterator$vmethods	java_util_Collections__24UnmodifiableIterator;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableIterator$sub_refs {
	struct _jc_object	*i;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableIterator$refs {
    _jc_java_util_Collections__24UnmodifiableIterator$sub_refs	java_util_Collections__24UnmodifiableIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs	java_util_Collections__24UnmodifiableIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableIterator$object {
	_jc_java_util_Collections__24UnmodifiableIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableIterator$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableIterator$vtype _jc_java_util_Collections__24UnmodifiableIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableIterator$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableIterator_H_ */
